@@ -42,8 +42,6 @@
 #define INIT_PORT	-1
 #define NULL_VALUE	0
 
-#define BRAILLE_FONT_INSTALL_ERROR_TEXT N_("Can not install braille font.")
-
 #ifdef INET6
     #define	FL_AF_INET AF_INET6
 #else
@@ -202,34 +200,6 @@ main (gint argc, gchar *argv[])
     sru_log_init ();
 
     
-    if (g_file_test ("braille_fonts", G_FILE_TEST_IS_DIR))
-    {
-    	system ("cd braille_fonts && mkfontdir && cd ..");
-    }
-    else
-    if (g_file_test ("../brlmon/braille_fonts", G_FILE_TEST_IS_DIR))
-    {
-	system ("cd ../brlmon/braille_fonts && mkfontdir && cd ../../gnopi");
-    }
-    
-    if (g_file_test ("braille_fonts/fonts.dir", G_FILE_TEST_EXISTS))
-    {
-	if (system ("xset fp+ `pwd`/braille_fonts") == -1)
-	    sru_warning (BRAILLE_FONT_INSTALL_ERROR_TEXT); 
-    }
-    else
-    if (g_file_test ("../brlmon/braille_fonts/fonts.dir", G_FILE_TEST_EXISTS))
-    {
-	if (system ("xset fp+ `pwd`/../brlmon/braille_fonts") == -1)
-	    sru_warning (BRAILLE_FONT_INSTALL_ERROR_TEXT); 
-    }
-    else 
-    if (g_file_test (BRLMON_BRAILLE_FONTS_DIR "fonts.dir", G_FILE_TEST_EXISTS))
-    {
-	if (system ("xset fp+ "BRLMON_BRAILLE_FONTS_DIR) == -1)
-	    sru_warning (BRAILLE_FONT_INSTALL_ERROR_TEXT); 
-    }
-
     gtk_init (&argc, &argv);
 
     rv = brlmon_gconf_client_init ();
