@@ -97,20 +97,20 @@
 
 /*____________________________< SRCORE_DEFAULTS>____________________________*/
 /*____________________________< SPEECH_DEFAULTS>____________________________*/
-#define SPEECH_RATE_STEP			5
+#define SPEECH_RATE_STEP			15
 #define SPEECH_VOLUME_STEP			5
-#define SPEECH_PITCH_STEP			5
+#define SPEECH_PITCH_STEP			25
 
-#define MAX_SPEECH_RATE				100
-#define MIN_SPEECH_RATE				0
-#define MAX_SPEECH_PITCH 			100
-#define MIN_SPEECH_PITCH 			0
+#define MAX_SPEECH_RATE				400
+#define MIN_SPEECH_RATE				100
+#define MAX_SPEECH_PITCH 			500
+#define MIN_SPEECH_PITCH 			10
 #define MAX_SPEECH_VOLUME 			100
 #define MIN_SPEECH_VOLUME 			0
 
 #define DEFAULT_SPEECH_PREEMPT 			TRUE
-#define DEFAULT_SPEECH_RATE 			80
-#define DEFAULT_SPEECH_PITCH 			80
+#define DEFAULT_SPEECH_RATE 			150
+#define DEFAULT_SPEECH_PITCH 			100
 #define DEFAULT_SPEECH_VOLUME 			100
 #define DEFAULT_SPEECH_COUNT_TYPE		"NONE"
 #define DEFAULT_SPEECH_VOICE_COUNT		0
@@ -120,8 +120,8 @@
 #define DEFAULT_SPEECH_MODIFIERS		"NONE"
 #define DEFAULT_SPEECH_CURSORS			"NONE"
 #define DEFAULT_SPEECH_SPACES			"ALL"
-#define DEFAULT_SPEECH_ENGINE_VOICE		"V0 Adult Male 1 - IBM Viavoice GNOME Speech Driver"
-#define DEFAULT_SPEECH_ENGINE_DRIVER 		"IBM Viavoice GNOME Speech Driver"
+#define DEFAULT_SPEECH_ENGINE_VOICE		"V0 kevin - FreeTTS Gnome Speech Driver"
+#define DEFAULT_SPEECH_ENGINE_DRIVER 		"FreeTTS_Gnome_Speech_Driver"
 #define DEFAULT_SPEECH_DICTIONARY_ACTIVE	"NO"
 #define DEFAULT_SPEECH_DICTIONARY_ENTRY 	"USA<>United States Of America" 
 /*____________________________< /SPEECH_DEFAULTS>___________________________*/
