@@ -28,10 +28,10 @@
 gboolean src_presentation_init 	    (gchar *fname);
 gboolean src_presentation_terminate ();
 
-gchar* src_presentation_present_sro_for_speech    (SRObject *obj, const gchar *reason);
-gchar* src_presentation_present_sro_for_magnifier (SRObject *obj, const gchar *reason);
-gchar* src_presentation_present_sro_for_braille   (SRObject *obj, const gchar *reason);
-gchar* src_presentation_present_sro_for_device 	  (SRObject *obj, const gchar *reason,
+gchar* src_presentation_sro_get_pres_for_speech    (SRObject *obj, const gchar *reason);
+gchar* src_presentation_sro_get_pres_for_magnifier (SRObject *obj, const gchar *reason);
+gchar* src_presentation_sro_get_pres_for_braille   (SRObject *obj, const gchar *reason);
+gchar* src_presentation_sro_get_pres_for_device    (SRObject *obj, const gchar *reason,
 						     const gchar *device);
 
 G_CONST_RETURN gchar* src_pres_get_role_name_for_speech (const gchar *role);
