@@ -205,6 +205,7 @@ typedef GList SRWElements;
 				   ( (a) != SPI_ROLE_MENU) 	&&	\
 				   ( (a) != -1) )
 #define MAX_PIXELS_PER_COLUMNS	 10000
+#define MIN_PIXELS_PER_COLUMNS	 2
 /*______________________________</MACROS>_____________________________________*/
 
 /*______________________________< GLOBALS>____________________________________*/
@@ -843,8 +844,11 @@ srw_text_chunk_from_accessible (Accessible	*accessible,
 		    text_chunk->end_offset = end ;
 
 		    if (text_chunk->text_bounds.width > 0 && string && g_utf8_strlen (string, -1) )
+		    {
 			pixels_per_column = MIN (text_chunk->text_bounds.width / g_utf8_strlen (string, -1),
 						pixels_per_column);
+			pixels_per_column = MAX (pixels_per_column, MIN_PIXELS_PER_COLUMNS);
+		    }
 		}
 		AccessibleText_unref (text);
 		no_need = FALSE;
@@ -886,9 +890,14 @@ srw_text_chunk_from_accessible (Accessible	*accessible,
 			text_chunk->text_bounds = text_chunk->clip_bounds;
 			text_chunk->start_offset = 0;
 			text_chunk->end_offset = strlen (string);
+
 			if (text_chunk->text_bounds.width > 0 && string && g_utf8_strlen (string,-1) )
+			{
 			    pixels_per_column = MIN (text_chunk->text_bounds.width / g_utf8_strlen (string, -1),
 						pixels_per_column);
+			    pixels_per_column = MAX (pixels_per_column, MIN_PIXELS_PER_COLUMNS);
+			}						
+
 #ifdef SRW_TEXT_CHUNK_DEBUG
 		fprintf (stderr, "\n\nsrw_text_chunk_from_accessible: NOT text |%s| %20s",
 				    string, 
